#
# spec file for package python-certbot-nginx
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?sle15_python_module_pythons}
Name:           python-certbot-nginx
Version:        4.0.0
Release:        1.1
Summary:        Nginx plugin for Certbot
License:        Apache-2.0
URL:            https://github.com/letsencrypt/letsencrypt
Source:         https://files.pythonhosted.org/packages/source/c/certbot-nginx/certbot_nginx-%{version}.tar.gz
BuildRequires:  %{python_module certbot >= %{version}}
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pyOpenSSL >= 25.0.0}
BuildRequires:  %{python_module pyparsing >= 2.4.7}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  nginx
BuildRequires:  python-rpm-macros
Requires:       nginx
Requires:       python-acme >= %{version}
Requires:       python-certbot >= %{version}
Requires:       python-pyOpenSSL >= 25.0.0
Requires:       python-pyparsing >= 2.4.7
BuildArch:      noarch
%python_subpackages

%description
The Nginx plugin for Certbot.

%prep
%setup -q -n certbot_nginx-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc README.rst
%license LICENSE.txt
%{python_sitelib}/certbot_nginx
%{python_sitelib}/certbot_nginx-%{version}*info

%changelog
* Tue Apr 22 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 4.0.0:
  * Added
    + The --preferred-profile and --required-profile flags allow requesting
    a profile.
  * Changed
    + Certificates now renew with 1/3rd of lifetime left (or 1/2 of lifetime
    left, if the lifetime is shorter than 10 days).
    + removed acme.crypto_util._pyopenssl_cert_or_req_all_names
    + removed acme.crypto_util._pyopenssl_cert_or_req_san
    + removed acme.crypto_util.dump_pyopenssl_chain
    + removed acme.crypto_util.gen_ss_cert
    + removed certbot.crypto_util.dump_pyopenssl_chain
    + removed certbot.crypto_util.pyopenssl_load_certificate
  * Fixed
    + Moved RewriteEngine on directive added during apache http01
    authentication to the end of the virtual host, so that it overwrites
    any RewriteEngine off directives that already exist and allows
    redirection to the challenge URL.
* Fri Mar 21 2025 Markéta Machová <mmachova@suse.com>
- update to version 3.3.0
  * certbot-nginx now requires pyOpenSSL>=25.0.0.
  * certbot-nginx now requires pyparsing>=2.4.7.
  * Allow nginx plugin to parse non-breaking spaces in nginx
    configuration files.
  * When adding ssl listen directives in nginx server blocks,
    IP addresses are now preserved.
  * Nginx configurations can now have the http block in files other
    than the root (nginx.conf)
  * Nginx server_name directives with internal comments now ignore
    commented names
* Mon Jan 27 2025 Markéta Machová <mmachova@suse.com>
- update to version 3.1.0
  * sync with the main certbot package
- convert to pip-based build
* Tue Dec  3 2024 Markéta Machová <mmachova@suse.com>
- update to version 3.0.1
  * sync with the main certbot package
* Tue Jun 25 2024 Markéta Machová <mmachova@suse.com>
- update to version 2.11.0
  * sync with the main certbot package
* Thu Mar 14 2024 Dirk Müller <dmueller@suse.com>
- update to 2.9.0:
  * sync with the main certbot package
* Wed Feb  7 2024 Markéta Machová <mmachova@suse.com>
- Add %%{?sle15_python_module_pythons}
* Thu Dec  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.8.0
  * sync with the main certbot package
* Thu Nov 16 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.4
  * sync with the main certbot package
* Tue Oct 31 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.7.3
  * sync with the main certbot package
* Wed Jun  7 2023 Markéta Machová <mmachova@suse.com>
- update to version 2.6.0
  * Support for Python 3.11 was added to Certbot and all of its components.
  * All Certbot components now require pytest to run tests.
  * Packaged tests for all Certbot components besides josepy were moved inside the _internal/tests module.
  * There is now a new Other annotated challenge object to allow plugins to support entirely novel challenges.
* Thu Oct 27 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.31.0
  * sync with the main certbot package
* Wed Sep 21 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.30.0
  * sync with the main certbot package
* Mon Jul 11 2022 Dirk Müller <dmueller@suse.com>
- update to 1.29.0:
  * --allow-subset-of-names will now additionally retry in cases where domains
    are rejected while creating or finalizing orders. This requires subproblem
    support from the ACME server
  * The show_account subcommand now uses the "newAccount" ACME endpoint to
    fetch the account data, so it doesn't rely on the locally stored account URL.
    This fixes situations where Certbot
    would use old ACMEv1 registration info with non-functional account URLs.
  * The generated Certificate Signing Requests are now generated as version 1
    instead of version 3. This resolves situations in where strict enforcement
    of PKCS#10 meant that CSRs that were generated as version 3 were rejected
* Fri Jun 24 2022 Dirk Müller <dmueller@suse.com>
- update to 1.28.0:
  * Updated Apache/NGINX TLS configs to document contents are based on ssl-config.mozilla.org
  * A change to order finalization has been made to the `acme` module and Certbot:
  - An order's `certificate` field will only be processed if the order's `status` is `valid`.
  - An order's `error` field will only be processed if the order's `status` is `invalid`.
* Mon May 30 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.27.0
  * sync with the main certbot package
* Fri Apr  8 2022 Markéta Machová <mmachova@suse.com>
- update to version 1.26.0
  * certbot-nginx now requires pyparsing>=2.2.1.
  * Nginx plugin now checks included files for the singleton server_names_hash_bucket_size directive.
* Tue Dec 21 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.22.0
  * sync with the main certbot package
* Mon Dec 13 2021 Ferdinand Thiessen <rpm@fthiessen.de>
- update to version 1.20.0
  * sync with the main certbot package
* Tue Aug 10 2021 Danilo Spinella <danilo.spinella@suse.com>
- update to version 1.18.0
  * sync with the main certbot package
* Fri Jul 30 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.17.0
  * When we increased the logging level on our nginx "Could not parse file" message,
    it caused a previously-existing inability to parse empty files to become more
    visible. We have now added the ability to correctly parse empty files, so that
    message should only show for more significant errors.
* Thu Jun 24 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.16.0
  * Require the latest certbot and acme plugins for simplicity
* Wed May 12 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.15.0
  * sync with the main certbot package
* Wed Apr 14 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.14.0
  * sync with the main certbot package
* Mon Mar  8 2021 Markéta Machová <mmachova@suse.com>
- update to version 1.13.0
  * Support for Python 2 has been removed.
  * The nginx authenticator now configures all matching HTTP and HTTPS vhosts for the HTTP-01
    challenge. It is now compatible with external HTTPS redirection by a CDN or load balancer.
* Fri Jan  8 2021 Antonio Larrosa <alarrosa@suse.com>
- update to version 1.11.0
  * sync with the main certbot package
- update to version 1.10.1
  * sync with the main certbot package
- update to version 1.10.0
  * Support for Python 3.9 was added to Certbot and all of its
    components.
  * Fixed a Unicode-related crash in the nginx plugin when running
    under Python 2.
* Wed Oct  7 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.9.0
  * Reduced CLI logging when reloading nginx, if it is not running.
  * Fixed server_name case-sensitivity in the nginx plugin.
* Fri Aug 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.7.0
  * Added --nginx-sleep-seconds (default 1) for environments where nginx takes a long time to reload.
* Mon Jul 13 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.6.0
  * Sync with main certbot package.
* Thu Jun 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.5.0
  * Sync with main certbot package.
* Thu May 14 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.4.0
  * Fix nginx plugin crash when non-ASCII configuration file is being read (instead,
    the user will be warned that UTF-8 must be used).
* Wed Mar 11 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.3.0
  * Sync with main certbot package.
* Fri Feb 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.2.0
  * Added support for $hostname in nginx server_name directive
  * Remove ECDHE-RSA-AES128-SHA from NGINX ciphers list
* Tue Jan 21 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.1.0
  * Sync with main certbot package.
* Fri Jan  3 2020 Marketa Calabkova <mcalabkova@suse.com>
- update to version 1.0.0 (boo#1160066)
  * The docs extras for the certbot-apache and certbot-nginx
    packages have been removed.
* Thu Nov 14 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.40.1
  * Sync with main certbot package.
* Thu Oct 17 2019 Richard Brown <rbrown@suse.com>
- Remove obsolete Groups tag (fate#326485)
* Wed Oct  2 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.39.0
  * Support for Python 3.8 was added to Certbot and all of its components.
* Wed Sep 11 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.38.0
  * Disable session tickets for Nginx users when appropriate.
* Mon Aug 26 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.37.2
  * Follow updated Mozilla recommendations for Nginx ssl_protocols,
    ssl_ciphers, and ssl_prefer_server_ciphers
  * Stop disabling TLS session tickets in Nginx as it caused TLS
    failures on some systems.
* Wed Jul 17 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.36.0 (bsc#1141928)
  * Turn off session tickets for nginx plugin by default
* Tue Jun 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.35.1
  * sync with main certbot package
* Sat May 18 2019 Dirk Mueller <dmueller@suse.com>
- update to 0.34.0
  * update for main certbot package
* Mon Mar 18 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.32.0
  * Tests execution now relies on pytest.
* Fri Feb  8 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.31.0
  * sync with main certbot package
* Tue Jan 29 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to version 0.30.2:
  * lockstep update with the main package
* Fri Nov 16 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.28.0
  * Stop preferring TLS-SNI.
  * Match Nginx parser update in allowing variable names to start
    with ${.
  * Fix ranking of vhosts in Nginx so that all port-matching
    vhosts come first.
* Fri Sep 14 2018 Marketa Calabkova <mcalabkova@suse.com>
- update to version 0.27.1
  * sync with main certbot package
* Mon Sep  3 2018 Marketa Calabkova <mcalabkova@suse.com>
- Launch tests and update runtime requirements
* Wed Aug 29 2018 mcalabkova@suse.com
- Split the module from the main certboot package
